mysql.exceptions.server

Package mysql :: Package exceptions :: Module server |
[hide private]
[frames] | no frames]

# Source Code for Module mysql.exceptions.server

       1  # $Header: /home/cvs2/mysql/mysql/exceptions/server.py,v 1.5 2006/11/13 02:39:08 ehuss Exp $
       2  # Copyright (c) 2006, Eric Huss
       3  # All rights reserved.
       4  #
       5  # Redistribution and use in source and binary forms, with or without
       6  # modification, are permitted provided that the following conditions are met:
       7  #
       8  # 1. Redistributions of source code must retain the above copyright notice,
       9  #    this list of conditions and the following disclaimer.
      10  # 2. Redistributions in binary form must reproduce the above copyright notice,
      11  #    this list of conditions and the following disclaimer in the documentation
      12  #    and/or other materials provided with the distribution.
      13  # 3. Neither the name of Eric Huss nor the names of any contributors may be
      14  #    used to endorse or promote products derived from this software without
      15  #    specific prior written permission.
      16  #
      17  # THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
      18  # AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
      19  # IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
      20  # ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
      21  # LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
      22  # CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
      23  # SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
      24  # INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
      25  # CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
      26  # ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
      27  # POSSIBILITY OF SUCH DAMAGE.
      28
      29  """Exceptions from the MySQL server.
      30
      31  These are all errors that the server-side of the MySQL API may generate.
      32
      33  Because older clients may connect to newer versions of the server, the server
      34  may generate new errors that this client is not aware of.  In this case, the
      35  exception `mysql.exceptions.client.Unknown_Error` is raised.
      36  """
      37
      38  __version__ = '$Revision: 1.5 $'
      39
      40  from mysql.exceptions.base import MySQL_Error
      41
      42 -class Hashchk(MySQL_Error):
      43
      44      """hashchk """
      45
      46 -class Nisamchk(MySQL_Error):
      47
      48      """isamchk"""
      49
      50 -class No(MySQL_Error):
      51
      52      """NO"""
      53
      54 -class Yes(MySQL_Error):
      55
      56      """YES"""
      57
      58 -class Cant_Create_File(MySQL_Error):
      59
      60      """Can't create file '%s' (errno: %d)"""
      61
      62 -class Cant_Create_Table(MySQL_Error):
      63
      64      """Can't create table '%s' (errno: %d)"""
      65
      66 -class Cant_Create_DB(MySQL_Error):
      67
      68      """Can't create database '%s' (errno: %d)"""
      69
      70 -class DB_Create_Exists(MySQL_Error):
      71
      72      """Can't create database '%s'; database exists"""
      73
      74 -class DB_Drop_Exists(MySQL_Error):
      75
      76      """Can't drop database '%s'; database doesn't exist"""
      77
      78 -class DB_Drop_Delete(MySQL_Error):
      79
      80      """Error dropping database (can't delete '%s', errno: %d)"""
      81
      82 -class DB_Drop_Rmdir(MySQL_Error):
      83
      84      """Error dropping database (can't rmdir '%s', errno: %d)"""
      85
      86 -class Cant_Delete_File(MySQL_Error):
      87
      88      """Error on delete of '%s' (errno: %d)"""
      89
      90 -class Cant_Find_System_Rec(MySQL_Error):
      91
      92      """Can't read record in system table"""
      93
      94 -class Cant_Get_Stat(MySQL_Error):
      95
      96      """Can't get status of '%s' (errno: %d)"""
      97
      98 -class Cant_Get_Wd(MySQL_Error):
      99
     100      """Can't get working directory (errno: %d)"""
     101
     102 -class Cant_Lock(MySQL_Error):
     103
     104      """Can't lock file (errno: %d)"""
     105
     106 -class Cant_Open_File(MySQL_Error):
     107
     108      """Can't open file: '%s' (errno: %d)"""
     109
     110 -class File_Not_Found(MySQL_Error):
     111
     112      """Can't find file: '%s' (errno: %d)"""
     113
     114 -class Cant_Read_Dir(MySQL_Error):
     115
     116      """Can't read dir of '%s' (errno: %d)"""
     117
     118 -class Cant_Set_Wd(MySQL_Error):
     119
     120      """Can't change dir to '%s' (errno: %d)"""
     121
     122 -class Checkread(MySQL_Error):
     123
     124      """Record has changed since last read in table '%s'"""
     125
     126 -class Disk_Full(MySQL_Error):
     127
     128      """Disk full (%s); waiting for someone to free some space..."""
     129
     130 -class Dup_Key(MySQL_Error):
     131
     132      """Can't write; duplicate key in table '%s'"""
     133
     134 -class Error_On_Close(MySQL_Error):
     135
     136      """Error on close of '%s' (errno: %d)"""
     137
     138 -class Error_On_Read(MySQL_Error):
     139
     140      """Error reading file '%s' (errno: %d)"""
     141
     142 -class Error_On_Rename(MySQL_Error):
     143
     144      """Error on rename of '%s' to '%s' (errno: %d)"""
     145
     146 -class Error_On_Write(MySQL_Error):
     147
     148      """Error writing file '%s' (errno: %d)"""
     149
     150 -class File_Used(MySQL_Error):
     151
     152      """'%s' is locked against change"""
     153
     154 -class Filsort_Abort(MySQL_Error):
     155
     156      """Sort aborted"""
     157
     158 -class Form_Not_Found(MySQL_Error):
     159
     160      """View '%s' doesn't exist for '%s'"""
     161
     162 -class Get_Errno(MySQL_Error):
     163
     164      """Got error %d from storage engine"""
     165
     166 -class Illegal_Ha(MySQL_Error):
     167
     168      """Table storage engine for '%s' doesn't have this option"""
     169
     170 -class Key_Not_Found(MySQL_Error):
     171
     172      """Can't find record in '%s'"""
     173
     174 -class Not_Form_File(MySQL_Error):
     175
     176      """Incorrect information in file: '%s'"""
     177
     178 -class Not_Keyfile(MySQL_Error):
     179
     180      """Incorrect key file for table '%s'; try to repair it"""
     181
     182 -class Old_Keyfile(MySQL_Error):
     183
     184      """Old key file for table '%s'; repair it!"""
     185
     186 -class Open_As_Readonly(MySQL_Error):
     187
     188      """Table '%s' is read only"""
     189
     190 -class Outofmemory(MySQL_Error):
     191
     192      """Out of memory; restart server and try again (needed %d bytes)"""
     193
     194 -class Out_Of_Sortmemory(MySQL_Error):
     195
     196      """Out of sort memory; increase server sort buffer size"""
     197
     198 -class Unexpected_Eof(MySQL_Error):
     199
     200      """Unexpected EOF found when reading file '%s' (errno: %d)"""
     201
     202 -class Con_Count_Error(MySQL_Error):
     203
     204      """Too many connections"""
     205
     206 -class Out_Of_Resources(MySQL_Error):
     207
     208      """Out of memory; check if mysqld or some other process uses all available
     209      memory; if not, you may have to use 'ulimit' to allow mysqld to use more
     210      memory or you can add more swap space
     211      """
     212
     213 -class Bad_Host_Error(MySQL_Error):
     214
     215      """Can't get hostname for your address"""
     216
     217 -class Handshake_Error(MySQL_Error):
     218
     219      """Bad handshake"""
     220
     221 -class DB_Access_Denied_Error(MySQL_Error):
     222
     223      """Access denied for user '%s'@'%s' to database '%s'"""
     224
     225 -class Access_Denied_Error(MySQL_Error):
     226
     227      """Access denied for user '%s'@'%s' (using password: %s)"""
     228
     229 -class No_DB_Error(MySQL_Error):
     230
     231      """No database selected"""
     232
     233 -class Unknown_Com_Error(MySQL_Error):
     234
     235      """Unknown command"""
     236
     237 -class Bad_Null_Error(MySQL_Error):
     238
     239      """Column '%s' cannot be null"""
     240
     241 -class Bad_DB_Error(MySQL_Error):
     242
     243      """Unknown database '%s'"""
     244
     245 -class Table_Exists_Error(MySQL_Error):
     246
     247      """Table '%s' already exists"""
     248
     249 -class Bad_Table_Error(MySQL_Error):
     250
     251      """Unknown table '%s'"""
     252
     253 -class Non_Uniq_Error(MySQL_Error):
     254
     255      """Column '%s' in %s is ambiguous"""
     256
     257 -class Server_Shutdown(MySQL_Error):
     258
     259      """Server shutdown in progress"""
     260
     261 -class Bad_Field_Error(MySQL_Error):
     262
     263      """Unknown column '%s' in '%s'"""
     264
     265 -class Wrong_Field_With_Group(MySQL_Error):
     266
     267      """'%s' isn't in GROUP BY"""
     268
     269 -class Wrong_Group_Field(MySQL_Error):
     270
     271      """Can't group on '%s'"""
     272
     273 -class Wrong_Sum_Select(MySQL_Error):
     274
     275      """Statement has sum functions and columns in same statement"""
     276
     277 -class Wrong_Value_Count(MySQL_Error):
     278
     279      """Column count doesn't match value count"""
     280
     281 -class Too_Long_Ident(MySQL_Error):
     282
     283      """Identifier name '%s' is too long"""
     284
     285 -class Dup_Fieldname(MySQL_Error):
     286
     287      """Duplicate column name '%s'"""
     288
     289 -class Dup_Keyname(MySQL_Error):
     290
     291      """Duplicate key name '%s'"""
     292
     293 -class Dup_Entry(MySQL_Error):
     294
     295      """Duplicate entry '%s' for key %d"""
     296
     297 -class Wrong_Field_Spec(MySQL_Error):
     298
     299      """Incorrect column specifier for column '%s'"""
     300
     301 -class Parse_Error(MySQL_Error):
     302
     303      """%s near '%s' at line %d"""
     304
     305 -class Empty_Query(MySQL_Error):
     306
     307      """Query was empty"""
     308
     309 -class Nonuniq_Table(MySQL_Error):
     310
     311      """Not unique table/alias: '%s'"""
     312
     313 -class Invalid_Default(MySQL_Error):
     314
     315      """Invalid default value for '%s'"""
     316
     317 -class Multiple_Pri_Key(MySQL_Error):
     318
     319      """Multiple primary key defined"""
     320
     321 -class Too_Many_Keys(MySQL_Error):
     322
     323      """Too many keys specified; max %d keys allowed"""
     324
     325 -class Too_Many_Key_Parts(MySQL_Error):
     326
     327      """Too many key parts specified; max %d parts allowed"""
     328
     329 -class Too_Long_Key(MySQL_Error):
     330
     331      """Specified key was too long; max key length is %d bytes"""
     332
     333 -class Key_Column_Does_Not_Exits(MySQL_Error):
     334
     335      """Key column '%s' doesn't exist in table"""
     336
     337 -class Blob_Used_As_Key(MySQL_Error):
     338
     339      """BLOB column '%s' can't be used in key specification with the used table
     340      type
     341      """
     342
     343 -class Too_Big_Fieldlength(MySQL_Error):
     344
     345      """Column length too big for column '%s' (max = %d); use BLOB or TEXT
     346      instead
     347      """
     348
     349 -class Wrong_Auto_Key(MySQL_Error):
     350
     351      """Incorrect table definition; there can be only one auto column and it
     352      must be defined as a key
     353      """
     354
     355 -class Ready(MySQL_Error):
     356
     357      """%s: ready for connections. Version: '%s' socket: '%s' port: %d"""
     358
     359 -class Normal_Shutdown(MySQL_Error):
     360
     361      """%s: Normal shutdown"""
     362
     363 -class Got_Signal(MySQL_Error):
     364
     365      """%s: Got signal %d. Aborting!"""
     366
     367 -class Shutdown_Complete(MySQL_Error):
     368
     369      """%s: Shutdown complete"""
     370
     371 -class Forcing_Close(MySQL_Error):
     372
     373      """%s: Forcing close of thread %ld user: '%s'"""
     374
     375 -class Ipsock_Error(MySQL_Error):
     376
     377      """Can't create IP socket"""
     378
     379 -class No_Such_Index(MySQL_Error):
     380
     381      """Table '%s' has no index like the one used in CREATE INDEX; recreate the
     382      table
     383      """
     384
     385 -class Wrong_Field_Terminators(MySQL_Error):
     386
     387      """Field separator argument is not what is expected; check the manual"""
     388
     389 -class Blobs_And_No_Terminated(MySQL_Error):
     390
     391      """You can't use fixed rowlength with BLOBs; please use 'fields terminated
     392      by'
     393      """
     394
     395 -class Textfile_Not_Readable(MySQL_Error):
     396
     397      """The file '%s' must be in the database directory or be readable by all"""
     398
     399 -class File_Exists_Error(MySQL_Error):
     400
     401      """File '%s' already exists"""
     402
     403 -class Load_Info(MySQL_Error):
     404
     405      """Records: %ld Deleted: %ld Skipped: %ld Warnings: %ld"""
     406
     407 -class Alter_Info(MySQL_Error):
     408
     409      """Records: %ld Duplicates: %ld"""
     410
     411 -class Wrong_Sub_Key(MySQL_Error):
     412
     413      """Incorrect sub part key; the used key part isn't a string, the used
     414      length is longer than the key part, or the storage engine doesn't support
     415      unique sub keys
     416      """
     417
     418 -class Cant_Remove_All_Fields(MySQL_Error):
     419
     420      """You can't delete all columns with ALTER TABLE; use DROP TABLE instead"""
     421
     422 -class Cant_Drop_Field_Or_Key(MySQL_Error):
     423
     424      """Can't DROP '%s'; check that column/key exists"""
     425
     426 -class Insert_Info(MySQL_Error):
     427
     428      """Records: %ld Duplicates: %ld Warnings: %ld"""
     429
     430 -class Update_Table_Used(MySQL_Error):
     431
     432      """You can't specify target table '%s' for update in FROM clause"""
     433
     434 -class No_Such_Thread(MySQL_Error):
     435
     436      """Unknown thread id: %lu"""
     437
     438 -class Kill_Denied_Error(MySQL_Error):
     439
     440      """You are not owner of thread %lu"""
     441
     442 -class No_Tables_Used(MySQL_Error):
     443
     444      """No tables used"""
     445
     446 -class Too_Big_Set(MySQL_Error):
     447
     448      """Too many strings for column %s and SET"""
     449
     450 -class No_Unique_Logfile(MySQL_Error):
     451
     452      """Can't generate a unique log-filename %s.(1-999)"""
     453
     454 -class Table_Not_Locked_For_Write(MySQL_Error):
     455
     456      """Table '%s' was locked with a READ lock and can't be updated"""
     457
     458 -class Table_Not_Locked(MySQL_Error):
     459
     460      """Table '%s' was not locked with LOCK TABLES"""
     461
     462 -class Blob_Cant_Have_Default(MySQL_Error):
     463
     464      """BLOB/TEXT column '%s' can't have a default value"""
     465
     466 -class Wrong_DB_Name(MySQL_Error):
     467
     468      """Incorrect database name '%s'"""
     469
     470 -class Wrong_Table_Name(MySQL_Error):
     471
     472      """Incorrect table name '%s'"""
     473
     474 -class Too_Big_Select(MySQL_Error):
     475
     476      """The SELECT would examine more than MAX_JOIN_SIZE rows; check your WHERE
     477      and use SET SQL_BIG_SELECTS=1 or SET SQL_MAX_JOIN_SIZE=# if the SELECT is
     478      okay
     479      """
     480
     481 -class Unknown_Error(MySQL_Error):
     482
     483      """Unknown error"""
     484
     485 -class Unknown_Procedure(MySQL_Error):
     486
     487      """Unknown procedure '%s'"""
     488
     489 -class Wrong_Paramcount_To_Procedure(MySQL_Error):
     490
     491      """Incorrect parameter count to procedure '%s'"""
     492
     493 -class Wrong_Parameters_To_Procedure(MySQL_Error):
     494
     495      """Incorrect parameters to procedure '%s'"""
     496
     497 -class Unknown_Table(MySQL_Error):
     498
     499      """Unknown table '%s' in %s"""
     500
     501 -class Field_Specified_Twice(MySQL_Error):
     502
     503      """Column '%s' specified twice"""
     504
     505 -class Invalid_Group_Func_Use(MySQL_Error):
     506
     507      """Invalid use of group function"""
     508
     509 -class Unsupported_Extension(MySQL_Error):
     510
     511      """Table '%s' uses an extension that doesn't exist in this MySQL version"""
     512
     513 -class Table_Must_Have_Columns(MySQL_Error):
     514
     515      """A table must have at least 1 column"""
     516
     517 -class Record_File_Full(MySQL_Error):
     518
     519      """The table '%s' is full"""
     520
     521 -class Unknown_Character_Set(MySQL_Error):
     522
     523      """Unknown character set: '%s'"""
     524
     525 -class Too_Many_Tables(MySQL_Error):
     526
     527      """Too many tables; MySQL can only use %d tables in a join"""
     528
     529 -class Too_Many_Fields(MySQL_Error):
     530
     531      """Too many columns"""
     532
     533 -class Too_Big_Rowsize(MySQL_Error):
     534
     535      """Row size too large. The maximum row size for the used table type, not
     536      counting BLOBs, is %ld. You have to change some columns to TEXT or BLOBs
     537      """
     538
     539 -class Stack_Overrun(MySQL_Error):
     540
     541      """Thread stack overrun: Used: %ld of a %ld stack. Use 'mysqld -O
     542      thread_stack=#' to specify a bigger stack if needed
     543      """
     544
     545 -class Wrong_Outer_Join(MySQL_Error):
     546
     547      """Cross dependency found in OUTER JOIN; examine your ON conditions"""
     548
     549 -class Null_Column_In_Index(MySQL_Error):
     550
     551      """Column '%s' is used with UNIQUE or INDEX but is not defined as NOT
     552      NULL
     553      """
     554
     555 -class Cant_Find_Udf(MySQL_Error):
     556
     557      """Can't load function '%s'"""
     558
     559 -class Cant_Initialize_Udf(MySQL_Error):
     560
     561      """Can't initialize function '%s'; %s"""
     562
     563 -class Udf_No_Paths(MySQL_Error):
     564
     565      """No paths allowed for shared library"""
     566
     567 -class Udf_Exists(MySQL_Error):
     568
     569      """Function '%s' already exists"""
     570
     571 -class Cant_Open_Library(MySQL_Error):
     572
     573      """Can't open shared library '%s' (errno: %d %s)"""
     574
     575 -class Cant_Find_Dl_Entry(MySQL_Error):
     576
     577      """Can't find function '%s' in library'"""
     578
     579 -class Function_Not_Defined(MySQL_Error):
     580
     581      """Function '%s' is not defined"""
     582
     583 -class Host_Is_Blocked(MySQL_Error):
     584
     585      """Host '%s' is blocked because of many connection errors; unblock with
     586      'mysqladmin flush-hosts'
     587      """
     588
     589 -class Host_Not_Privileged(MySQL_Error):
     590
     591      """Host '%s' is not allowed to connect to this MySQL server"""
     592
     593 -class Password_Anonymous_User(MySQL_Error):
     594
     595      """You are using MySQL as an anonymous user and anonymous users are not
     596      allowed to change passwords
     597      """
     598
     599 -class Password_Not_Allowed(MySQL_Error):
     600
     601      """You must have privileges to update tables in the mysql database to be
     602      able to change passwords for others
     603      """
     604
     605 -class Password_No_Match(MySQL_Error):
     606
     607      """Can't find any matching row in the user table"""
     608
     609 -class Update_Info(MySQL_Error):
     610
     611      """Rows matched: %ld Changed: %ld Warnings: %ld"""
     612
     613 -class Cant_Create_Thread(MySQL_Error):
     614
     615      """Can't create a new thread (errno %d); if you are not out of available
     616      memory, you can consult the manual for a possible OS-dependent bug
     617      """
     618
     619 -class Wrong_Value_Count_On_Row(MySQL_Error):
     620
     621      """Column count doesn't match value count at row %ld"""
     622
     623 -class Cant_Reopen_Table(MySQL_Error):
     624
     625      """Can't reopen table: '%s'"""
     626
     627 -class Invalid_Use_Of_Null(MySQL_Error):
     628
     629      """Invalid use of NULL value"""
     630
     631 -class Regexp_Error(MySQL_Error):
     632
     633      """Got error '%s' from regexp"""
     634
     635 -class Mix_Of_Group_Func_And_Fields(MySQL_Error):
     636
     637      """Mixing of GROUP columns (MIN(),MAX(),COUNT(),...) with no GROUP columns
     638      is illegal if there is no GROUP BY clause
     639      """
     640
     641 -class Nonexisting_Grant(MySQL_Error):
     642
     643      """There is no such grant defined for user '%s' on host '%s'"""
     644
     645 -class Tableaccess_Denied_Error(MySQL_Error):
     646
     647      """%s command denied to user '%s'@'%s' for table '%s'"""
     648
     649 -class Columnaccess_Denied_Error(MySQL_Error):
     650
     651      """%s command denied to user '%s'@'%s' for column '%s' in table '%s'"""
     652
     653 -class Illegal_Grant_For_Table(MySQL_Error):
     654
     655      """Illegal GRANT/REVOKE command; please consult the manual to see which
     656      privileges can be used
     657      """
     658
     659 -class Grant_Wrong_Host_Or_User(MySQL_Error):
     660
     661      """The host or user argument to GRANT is too long"""
     662
     663 -class No_Such_Table(MySQL_Error):
     664
     665      """Table '%s.%s' doesn't exist"""
     666
     667 -class Nonexisting_Table_Grant(MySQL_Error):
     668
     669      """There is no such grant defined for user '%s' on host '%s' on table '%s'"""
     670
     671 -class Not_Allowed_Command(MySQL_Error):
     672
     673      """The used command is not allowed with this MySQL version"""
     674
     675 -class Syntax_Error(MySQL_Error):
     676
     677      """You have an error in your SQL syntax; check the manual that corresponds
     678      to your MySQL server version for the right syntax to use
     679      """
     680
     681 -class Delayed_Cant_Change_Lock(MySQL_Error):
     682
     683      """Delayed insert thread couldn't get requested lock for table %s"""
     684
     685 -class Too_Many_Delayed_Threads(MySQL_Error):
     686
     687      """Too many delayed threads in use"""
     688
     689 -class Aborting_Connection(MySQL_Error):
     690
     691      """Aborted connection %ld to db: '%s' user: '%s' (%s)"""
     692
     693 -class Net_Packet_Too_Large(MySQL_Error):
     694
     695      """Got a packet bigger than 'max_allowed_packet' bytes"""
     696
     697 -class Net_Read_Error_From_Pipe(MySQL_Error):
     698
     699      """Got a read error from the connection pipe"""
     700
     701 -class Net_Fcntl_Error(MySQL_Error):
     702
     703      """Got an error from fcntl()"""
     704
     705 -class Net_Packets_Out_Of_Order(MySQL_Error):
     706
     707      """Got packets out of order"""
     708
     709 -class Net_Uncompress_Error(MySQL_Error):
     710
     711      """Couldn't uncompress communication packet"""
     712
     713 -class Net_Read_Error(MySQL_Error):
     714
     715      """Got an error reading communication packets"""
     716
     717 -class Net_Read_Interrupted(MySQL_Error):
     718
     719      """Got timeout reading communication packets"""
     720
     721 -class Net_Error_On_Write(MySQL_Error):
     722
     723      """Got an error writing communication packets"""
     724
     725 -class Net_Write_Interrupted(MySQL_Error):
     726
     727      """Got timeout writing communication packets"""
     728
     729 -class Too_Long_String(MySQL_Error):
     730
     731      """Result string is longer than 'max_allowed_packet' bytes"""
     732
     733 -class Table_Cant_Handle_Blob(MySQL_Error):
     734
     735      """The used table type doesn't support BLOB/TEXT columns"""
     736
     737 -class Table_Cant_Handle_Auto_Increment(MySQL_Error):
     738
     739      """The used table type doesn't support AUTO_INCREMENT columns"""
     740
     741 -class Delayed_Insert_Table_Locked(MySQL_Error):
     742
     743      """INSERT DELAYED can't be used with table '%s' because it is locked with
     744      LOCK TABLES
     745      """
     746
     747 -class Wrong_Column_Name(MySQL_Error):
     748
     749      """Incorrect column name '%s'"""
     750
     751 -class Wrong_Key_Column(MySQL_Error):
     752
     753      """The used storage engine can't index column '%s'"""
     754
     755 -class Wrong_Mrg_Table(MySQL_Error):
     756
     757      """All tables in the MERGE table are not identically defined"""
     758
     759 -class Dup_Unique(MySQL_Error):
     760
     761      """Can't write, because of unique constraint, to table '%s'"""
     762
     763 -class Blob_Key_Without_Length(MySQL_Error):
     764
     765      """BLOB/TEXT column '%s' used in key specification without a key length"""
     766
     767 -class Primary_Cant_Have_Null(MySQL_Error):
     768
     769      """All parts of a PRIMARY KEY must be NOT NULL; if you need NULL in a key,
     770      use UNIQUE instead
     771      """
     772
     773 -class Too_Many_Rows(MySQL_Error):
     774
     775      """Result consisted of more than one row"""
     776
     777 -class Requires_Primary_Key(MySQL_Error):
     778
     779      """This table type requires a primary key"""
     780
     781 -class No_Raid_Compiled(MySQL_Error):
     782
     783      """This version of MySQL is not compiled with RAID support"""
     784
     785 -class Update_Without_Key_In_Safe_Mode(MySQL_Error):
     786
     787      """You are using safe update mode and you tried to update a table without a
     788      WHERE that uses a KEY column
     789      """
     790
     791 -class Key_Does_Not_Exits(MySQL_Error):
     792
     793      """Key '%s' doesn't exist in table '%s'"""
     794
     795 -class Check_No_Such_Table(MySQL_Error):
     796
     797      """Can't open table"""
     798
     799 -class Check_Not_Implemented(MySQL_Error):
     800
     801      """The storage engine for the table doesn't support %s"""
     802
     803 -class Cant_Do_This_During_An_Transaction(MySQL_Error):
     804
     805      """You are not allowed to execute this command in a transaction"""
     806
     807 -class Error_During_Commit(MySQL_Error):
     808
     809      """Got error %d during COMMIT"""
     810
     811 -class Error_During_Rollback(MySQL_Error):
     812
     813      """Got error %d during ROLLBACK"""
     814
     815 -class Error_During_Flush_Logs(MySQL_Error):
     816
     817      """Got error %d during FLUSH_LOGS"""
     818
     819 -class Error_During_Checkpoint(MySQL_Error):
     820
     821      """Got error %d during CHECKPOINT"""
     822
     823 -class New_Aborting_Connection(MySQL_Error):
     824
     825      """Aborted connection %ld to db: '%s' user: '%s' host: '%s' (%s)"""
     826
     827 -class Dump_Not_Implemented(MySQL_Error):
     828
     829      """The storage engine for the table does not support binary table dump"""
     830
     831 -class Flush_Master_Binlog_Closed(MySQL_Error):
     832
     833      """Binlog closed, cannot RESET MASTER"""
     834
     835 -class Index_Rebuild(MySQL_Error):
     836
     837      """Failed rebuilding the index of dumped table '%s'"""
     838
     839 -class Master(MySQL_Error):
     840
     841      """Error from master: '%s'"""
     842
     843 -class Master_Net_Read(MySQL_Error):
     844
     845      """Net error reading from master"""
     846
     847 -class Master_Net_Write(MySQL_Error):
     848
     849      """Net error writing to master"""
     850
     851 -class Ft_Matching_Key_Not_Found(MySQL_Error):
     852
     853      """Can't find FULLTEXT index matching the column list"""
     854
     855 -class Lock_Or_Active_Transaction(MySQL_Error):
     856
     857      """Can't execute the given command because you have active locked tables or
     858      an active transaction
     859      """
     860
     861 -class Unknown_System_Variable(MySQL_Error):
     862
     863      """Unknown system variable '%s'"""
     864
     865 -class Crashed_On_Usage(MySQL_Error):
     866
     867      """Table '%s' is marked as crashed and should be repaired"""
     868
     869 -class Crashed_On_Repair(MySQL_Error):
     870
     871      """Table '%s' is marked as crashed and last (automatic?) repair failed"""
     872
     873 -class Warning_Not_Complete_Rollback(MySQL_Error):
     874
     875      """Some non-transactional changed tables couldn't be rolled back"""
     876
     877 -class Trans_Cache_Full(MySQL_Error):
     878
     879      """Multi-statement transaction required more than 'max_binlog_cache_size'
     880      bytes of storage; increase this mysqld variable and try again
     881      """
     882
     883 -class Slave_Must_Stop(MySQL_Error):
     884
     885      """This operation cannot be performed with a running slave; run STOP SLAVE
     886      first
     887      """
     888
     889 -class Slave_Not_Running(MySQL_Error):
     890
     891      """This operation requires a running slave; configure slave and do START
     892      SLAVE
     893      """
     894
     895 -class Bad_Slave(MySQL_Error):
     896
     897      """The server is not configured as slave; fix in config file or with CHANGE
     898      MASTER TO
     899      """
     900
     901 -class Master_Info(MySQL_Error):
     902
     903      """Could not initialize master info structure; more error messages can be
     904      found in the MySQL error log
     905      """
     906
     907 -class Slave_Thread(MySQL_Error):
     908
     909      """Could not create slave thread; check system resources"""
     910
     911 -class Too_Many_User_Connections(MySQL_Error):
     912
     913      """User %s already has more than 'max_user_connections' active
     914      connections
     915      """
     916
     917 -class Set_Constants_Only(MySQL_Error):
     918
     919      """You may only use constant expressions with SET"""
     920
     921 -class Lock_Wait_Timeout(MySQL_Error):
     922
     923      """Lock wait timeout exceeded; try restarting transaction"""
     924
     925 -class Lock_Table_Full(MySQL_Error):
     926
     927      """The total number of locks exceeds the lock table size"""
     928
     929 -class Read_Only_Transaction(MySQL_Error):
     930
     931      """Update locks cannot be acquired during a READ UNCOMMITTED transaction"""
     932
     933 -class Drop_DB_With_Read_Lock(MySQL_Error):
     934
     935      """DROP DATABASE not allowed while thread is holding global read lock"""
     936
     937 -class Create_DB_With_Read_Lock(MySQL_Error):
     938
     939      """CREATE DATABASE not allowed while thread is holding global read lock"""
     940
     941 -class Wrong_Arguments(MySQL_Error):
     942
     943      """Incorrect arguments to %s"""
     944
     945 -class No_Permission_To_Create_User(MySQL_Error):
     946
     947      """'%s'@'%s' is not allowed to create new users"""
     948
     949 -class Union_Tables_In_Different_Dir(MySQL_Error):
     950
     951      """Incorrect table definition; all MERGE tables must be in the same
     952      database
     953      """
     954
     955 -class Lock_Deadlock(MySQL_Error):
     956
     957      """Deadlock found when trying to get lock; try restarting transaction"""
     958
     959 -class Table_Cant_Handle_Ft(MySQL_Error):
     960
     961      """The used table type doesn't support FULLTEXT indexes"""
     962
     963 -class Cannot_Add_Foreign(MySQL_Error):
     964
     965      """Cannot add foreign key constraint"""
     966
     967 -class No_Referenced_Row(MySQL_Error):
     968
     969      """Cannot add or update a child row: a foreign key constraint fails"""
     970
     971 -class Row_Is_Referenced(MySQL_Error):
     972
     973      """Cannot delete or update a parent row: a foreign key constraint fails"""
     974
     975 -class Connect_To_Master(MySQL_Error):
     976
     977      """Error connecting to master: %s"""
     978
     979 -class Query_On_Master(MySQL_Error):
     980
     981      """Error running query on master: %s"""
     982
     983 -class Error_When_Executing_Command(MySQL_Error):
     984
     985      """Error when executing command %s: %s"""
     986
     987 -class Wrong_Usage(MySQL_Error):
     988
     989      """Incorrect usage of %s and %s"""
     990
     991 -class Wrong_Number_Of_Columns_In_Select(MySQL_Error):
     992
     993      """The used SELECT statements have a different number of columns"""
     994
     995 -class Cant_Update_With_Readlock(MySQL_Error):
     996
     997      """Can't execute the query because you have a conflicting read lock"""
     998
     999 -class Mixing_Not_Allowed(MySQL_Error):
    1000
    1001      """Mixing of transactional and non-transactional tables is disabled"""
    1002
    1003 -class Dup_Argument(MySQL_Error):
    1004
    1005      """Option '%s' used twice in statement"""
    1006
    1007 -class User_Limit_Reached(MySQL_Error):
    1008
    1009      """User '%s' has exceeded the '%s' resource (current value: %ld)"""
    1010
    1011 -class Specific_Access_Denied_Error(MySQL_Error):
    1012
    1013      """Access denied; you need the %s privilege for this operation"""
    1014
    1015 -class Local_Variable(MySQL_Error):
    1016
    1017      """Variable '%s' is a SESSION variable and can't be used with SET GLOBAL"""
    1018
    1019 -class Global_Variable(MySQL_Error):
    1020
    1021      """Variable '%s' is a GLOBAL variable and should be set with SET GLOBAL"""
    1022
    1023 -class No_Default(MySQL_Error):
    1024
    1025      """Variable '%s' doesn't have a default value"""
    1026
    1027 -class Wrong_Value_For_Var(MySQL_Error):
    1028
    1029      """Variable '%s' can't be set to the value of '%s'"""
    1030
    1031 -class Wrong_Type_For_Var(MySQL_Error):
    1032
    1033      """Incorrect argument type to variable '%s'"""
    1034
    1035 -class Var_Cant_Be_Read(MySQL_Error):
    1036
    1037      """Variable '%s' can only be set, not read"""
    1038
    1039 -class Cant_Use_Option_Here(MySQL_Error):
    1040
    1041      """Incorrect usage/placement of '%s'"""
    1042
    1043 -class Not_Supported_Yet(MySQL_Error):
    1044
    1045      """This version of MySQL doesn't yet support '%s'"""
    1046
    1047 -class Master_Fatal_Error_Reading_Binlog(MySQL_Error):
    1048
    1049      """Got fatal error %d: '%s' from master when reading data from binary
    1050      log
    1051      """
    1052
    1053 -class Slave_Ignored_Table(MySQL_Error):
    1054
    1055      """Slave SQL thread ignored the query because of replicate-\\*-table rules"""
    1056
    1057 -class Incorrect_Global_Local_Var(MySQL_Error):
    1058
    1059      """Variable '%s' is a %s variable"""
    1060
    1061 -class Wrong_Fk_Def(MySQL_Error):
    1062
    1063      """Incorrect foreign key definition for '%s': %s"""
    1064
    1065 -class Key_Ref_Do_Not_Match_Table_Ref(MySQL_Error):
    1066
    1067      """Key reference and table reference don't match"""
    1068
    1069 -class Operand_Columns(MySQL_Error):
    1070
    1071      """Operand should contain %d column(s)"""
    1072
    1073 -class Subquery_No_1_Row(MySQL_Error):
    1074
    1075      """Subquery returns more than 1 row"""
    1076
    1077 -class Unknown_Stmt_Handler(MySQL_Error):
    1078
    1079      """Unknown prepared statement handler (%.*s) given to %s"""
    1080
    1081 -class Corrupt_Help_DB(MySQL_Error):
    1082
    1083      """Help database is corrupt or does not exist"""
    1084
    1085 -class Cyclic_Reference(MySQL_Error):
    1086
    1087      """Cyclic reference on subqueries"""
    1088
    1089 -class Auto_Convert(MySQL_Error):
    1090
    1091      """Converting column '%s' from %s to %s"""
    1092
    1093 -class Illegal_Reference(MySQL_Error):
    1094
    1095      """Reference '%s' not supported (%s)"""
    1096
    1097 -class Derived_Must_Have_Alias(MySQL_Error):
    1098
    1099      """Every derived table must have its own alias"""
    1100
    1101 -class Select_Reduced(MySQL_Error):
    1102
    1103      """Select %u was reduced during optimization"""
    1104
    1105 -class Tablename_Not_Allowed_Here(MySQL_Error):
    1106
    1107      """Table '%s' from one of the SELECTs cannot be used in %s"""
    1108
    1109 -class Not_Supported_Auth_Mode(MySQL_Error):
    1110
    1111      """Client does not support authentication protocol requested by server;
    1112      consider upgrading MySQL client
    1113      """
    1114
    1115 -class Spatial_Cant_Have_Null(MySQL_Error):
    1116
    1117      """All parts of a SPATIAL index must be NOT NULL"""
    1118
    1119 -class Collation_Charset_Mismatch(MySQL_Error):
    1120
    1121      """COLLATION '%s' is not valid for CHARACTER SET '%s'"""
    1122
    1123 -class Slave_Was_Running(MySQL_Error):
    1124
    1125      """Slave is already running"""
    1126
    1127 -class Slave_Was_Not_Running(MySQL_Error):
    1128
    1129      """Slave already has been stopped"""
    1130
    1131 -class Too_Big_For_Uncompress(MySQL_Error):
    1132
    1133      """Uncompressed data size too large; the maximum size is %d (probably,
    1134      length of uncompressed data was corrupted)
    1135      """
    1136
    1137 -class Zlib_Z_Mem_Error(MySQL_Error):
    1138
    1139      """ZLIB: Not enough memory"""
    1140
    1141 -class Zlib_Z_Buf_Error(MySQL_Error):
    1142
    1143      """ZLIB: Not enough room in the output buffer (probably, length of
    1144      uncompressed data was corrupted)
    1145      """
    1146
    1147 -class Zlib_Z_Data_Error(MySQL_Error):
    1148
    1149      """ZLIB: Input data corrupted"""
    1150
    1151 -class Cut_Value_Group_Concat(MySQL_Error):
    1152
    1153      """%d line(s) were cut by GROUP_CONCAT()"""
    1154
    1155 -class Warn_Too_Few_Records(MySQL_Error):
    1156
    1157      """Row %ld doesn't contain data for all columns"""
    1158
    1159 -class Warn_Too_Many_Records(MySQL_Error):
    1160
    1161      """Row %ld was truncated; it contained more data than there were input
    1162      columns
    1163      """
    1164
    1165 -class Warn_Null_To_Notnull(MySQL_Error):
    1166
    1167      """Column set to default value; NULL supplied to NOT NULL column '%s' at
    1168      row %ld
    1169      """
    1170
    1171 -class Warn_Data_Out_Of_Range(MySQL_Error):
    1172
    1173      """Out of range value adjusted for column '%s' at row %ld"""
    1174
    1175 -class Warn_Data_Truncated(MySQL_Error):
    1176
    1177      """Data truncated for column '%s' at row %ld"""
    1178
    1179 -class Warn_Using_Other_Handler(MySQL_Error):
    1180
    1181      """Using storage engine %s for table '%s'"""
    1182
    1183 -class Cant_Aggregate_2Collations(MySQL_Error):
    1184
    1185      """Illegal mix of collations (%s,%s) and (%s,%s) for operation '%s'"""
    1186
    1187 -class Drop_User(MySQL_Error):
    1188
    1189      """Cannot drop one or more of the requested users"""
    1190
    1191 -class Revoke_Grants(MySQL_Error):
    1192
    1193      """Can't revoke all privileges, grant for one or more of the requested
    1194      users
    1195      """
    1196
    1197 -class Cant_Aggregate_3Collations(MySQL_Error):
    1198
    1199      """Illegal mix of collations (%s,%s), (%s,%s), (%s,%s) for operation
    1200      '%s'
    1201      """
    1202
    1203 -class Cant_Aggregate_Ncollations(MySQL_Error):
    1204
    1205      """Illegal mix of collations for operation '%s'"""
    1206
    1207 -class Variable_Is_Not_Struct(MySQL_Error):
    1208
    1209      """Variable '%s' is not a variable component (can't be used as
    1210      XXXX.variable_name)
    1211      """
    1212
    1213 -class Unknown_Collation(MySQL_Error):
    1214
    1215      """Unknown collation: '%s'"""
    1216
    1217 -class Slave_Ignored_Ssl_Params(MySQL_Error):
    1218
    1219      """SSL parameters in CHANGE MASTER are ignored because this MySQL slave was
    1220      compiled without SSL support; they can be used later if MySQL slave with
    1221      SSL is started
    1222      """
    1223
    1224 -class Server_Is_In_Secure_Auth_Mode(MySQL_Error):
    1225
    1226      """Server is running in --secure-auth mode, but '%s'@'%s' has a password in
    1227      the old format; please change the password to the new format
    1228      """
    1229
    1230 -class Warn_Field_Resolved(MySQL_Error):
    1231
    1232      """Field or reference '%s%s%s%s%s' of SELECT #%d was resolved in SELECT #%d"""
    1233
    1234 -class Bad_Slave_Until_Cond(MySQL_Error):
    1235
    1236      """Incorrect parameter or combination of parameters for START SLAVE UNTIL"""
    1237
    1238 -class Missing_Skip_Slave(MySQL_Error):
    1239
    1240      """It is recommended to use --skip-slave-start when doing step-by-step
    1241      replication with START SLAVE UNTIL; otherwise, you will get problems if you
    1242      get an unexpected slave's mysqld restart
    1243      """
    1244
    1245 -class Until_Cond_Ignored(MySQL_Error):
    1246
    1247      """SQL thread is not to be started so UNTIL options are ignored"""
    1248
    1249 -class Wrong_Name_For_Index(MySQL_Error):
    1250
    1251      """Incorrect index name '%s'"""
    1252
    1253 -class Wrong_Name_For_Catalog(MySQL_Error):
    1254
    1255      """Incorrect catalog name '%s'"""
    1256
    1257 -class Warn_Qc_Resize(MySQL_Error):
    1258
    1259      """Query cache failed to set size %lu; new query cache size is %lu"""
    1260
    1261 -class Bad_Ft_Column(MySQL_Error):
    1262
    1263      """Column '%s' cannot be part of FULLTEXT index"""
    1264
    1265 -class Unknown_Key_Cache(MySQL_Error):
    1266
    1267      """Unknown key cache '%s'"""
    1268
    1269 -class Warn_Hostname_Wont_Work(MySQL_Error):
    1270
    1271      """MySQL is started in --skip-name-resolve mode; you must restart it
    1272      without this switch for this grant to work
    1273      """
    1274
    1275 -class Unknown_Storage_Engine(MySQL_Error):
    1276
    1277      """Unknown table engine '%s'"""
    1278
    1279 -class Warn_Deprecated_Syntax(MySQL_Error):
    1280
    1281      """'%s' is deprecated; use '%s' instead"""
    1282
    1283 -class Non_Updatable_Table(MySQL_Error):
    1284
    1285      """The target table %s of the %s is not updatable"""
    1286
    1287 -class Feature_Disabled(MySQL_Error):
    1288
    1289      """The '%s' feature is disabled; you need MySQL built with '%s' to have it
    1290      working
    1291      """
    1292
    1293 -class Option_Prevents_Statement(MySQL_Error):
    1294
    1295      """The MySQL server is running with the %s option so it cannot execute this
    1296      statement
    1297      """
    1298
    1299 -class Duplicated_Value_In_Type(MySQL_Error):
    1300
    1301      """Column '%s' has duplicated value '%s' in %s"""
    1302
    1303 -class Truncated_Wrong_Value(MySQL_Error):
    1304
    1305      """Truncated incorrect %s value: '%s'"""
    1306
    1307 -class Too_Much_Auto_Timestamp_Cols(MySQL_Error):
    1308
    1309      """Incorrect table definition; there can be only one TIMESTAMP column with
    1310      CURRENT_TIMESTAMP in DEFAULT or ON UPDATE clause
    1311      """
    1312
    1313 -class Invalid_On_Update(MySQL_Error):
    1314
    1315      """Invalid ON UPDATE clause for '%s' column"""
    1316
    1317 -class Unsupported_Ps(MySQL_Error):
    1318
    1319      """This command is not supported in the prepared statement protocol yet"""
    1320
    1321 -class Get_Errmsg(MySQL_Error):
    1322
    1323      """Got error %d '%s' from %s"""
    1324
    1325 -class Get_Temporary_Errmsg(MySQL_Error):
    1326
    1327      """Got temporary error %d '%s' from %s"""
    1328
    1329 -class Unknown_Time_Zone(MySQL_Error):
    1330
    1331      """Unknown or incorrect time zone: '%s'"""
    1332
    1333 -class Warn_Invalid_Timestamp(MySQL_Error):
    1334
    1335      """Invalid TIMESTAMP value in column '%s' at row %ld"""
    1336
    1337 -class Invalid_Character_String(MySQL_Error):
    1338
    1339      """Invalid %s character string: '%s'"""
    1340
    1341 -class Warn_Allowed_Packet_Overflowed(MySQL_Error):
    1342
    1343      """Result of %s() was larger than max_allowed_packet (%ld) - truncated"""
    1344
    1345 -class Conflicting_Declarations(MySQL_Error):
    1346
    1347      """Conflicting declarations: '%s%s' and '%s%s'"""
    1348
    1349 -class Sp_No_Recursive_Create(MySQL_Error):
    1350
    1351      """Can't create a %s from within another stored routine"""
    1352
    1353 -class Sp_Already_Exists(MySQL_Error):
    1354
    1355      """%s %s already exists"""
    1356
    1357 -class Sp_Does_Not_Exist(MySQL_Error):
    1358
    1359      """%s %s does not exist"""
    1360
    1361 -class Sp_Drop_Failed(MySQL_Error):
    1362
    1363      """Failed to DROP %s %s"""
    1364
    1365 -class Sp_Store_Failed(MySQL_Error):
    1366
    1367      """Failed to CREATE %s %s"""
    1368
    1369 -class Sp_Lilabel_Mismatch(MySQL_Error):
    1370
    1371      """%s with no matching label: %s"""
    1372
    1373 -class Sp_Label_Redefine(MySQL_Error):
    1374
    1375      """Redefining label %s"""
    1376
    1377 -class Sp_Label_Mismatch(MySQL_Error):
    1378
    1379      """End-label %s without match"""
    1380
    1381 -class Sp_Uninit_Var(MySQL_Error):
    1382
    1383      """Referring to uninitialized variable %s"""
    1384
    1385 -class Sp_Badselect(MySQL_Error):
    1386
    1387      """PROCEDURE %s can't return a result set in the given context"""
    1388
    1389 -class Sp_Badreturn(MySQL_Error):
    1390
    1391      """RETURN is only allowed in a FUNCTION"""
    1392
    1393 -class Sp_Badstatement(MySQL_Error):
    1394
    1395      """%s is not allowed in stored procedures"""
    1396
    1397 -class Update_Log_Deprecated_Ignored(MySQL_Error):
    1398
    1399      """The update log is deprecated and replaced by the binary log; SET
    1400      SQL_LOG_UPDATE has been ignored
    1401      """
    1402
    1403 -class Update_Log_Deprecated_Translated(MySQL_Error):
    1404
    1405      """The update log is deprecated and replaced by the binary log; SET
    1406      SQL_LOG_UPDATE has been translated to SET SQL_LOG_BIN
    1407      """
    1408
    1409 -class Query_Interrupted(MySQL_Error):
    1410
    1411      """Query execution was interrupted"""
    1412
    1413 -class Sp_Wrong_No_Of_Args(MySQL_Error):
    1414
    1415      """Incorrect number of arguments for %s %s; expected %u, got %u"""
    1416
    1417 -class Sp_Cond_Mismatch(MySQL_Error):
    1418
    1419      """Undefined CONDITION: %s"""
    1420
    1421 -class Sp_Noreturn(MySQL_Error):
    1422
    1423      """No RETURN found in FUNCTION %s"""
    1424
    1425 -class Sp_Noreturnend(MySQL_Error):
    1426
    1427      """FUNCTION %s ended without RETURN"""
    1428
    1429 -class Sp_Bad_Cursor_Query(MySQL_Error):
    1430
    1431      """Cursor statement must be a SELECT"""
    1432
    1433 -class Sp_Bad_Cursor_Select(MySQL_Error):
    1434
    1435      """Cursor SELECT must not have INTO"""
    1436
    1437 -class Sp_Cursor_Mismatch(MySQL_Error):
    1438
    1439      """Undefined CURSOR: %s"""
    1440
    1441 -class Sp_Cursor_Already_Open(MySQL_Error):
    1442
    1443      """Cursor is already open"""
    1444
    1445 -class Sp_Cursor_Not_Open(MySQL_Error):
    1446
    1447      """Cursor is not open"""
    1448
    1449 -class Sp_Undeclared_Var(MySQL_Error):
    1450
    1451      """Undeclared variable: %s"""
    1452
    1453 -class Sp_Wrong_No_Of_Fetch_Args(MySQL_Error):
    1454
    1455      """Incorrect number of FETCH variables"""
    1456
    1457 -class Sp_Fetch_No_Data(MySQL_Error):
    1458
    1459      """No data to FETCH"""
    1460
    1461 -class Sp_Dup_Param(MySQL_Error):
    1462
    1463      """Duplicate parameter: %s"""
    1464
    1465 -class Sp_Dup_Var(MySQL_Error):
    1466
    1467      """Duplicate variable: %s"""
    1468
    1469 -class Sp_Dup_Cond(MySQL_Error):
    1470
    1471      """Duplicate condition: %s"""
    1472
    1473 -class Sp_Dup_Curs(MySQL_Error):
    1474
    1475      """Duplicate cursor: %s"""
    1476
    1477 -class Sp_Cant_Alter(MySQL_Error):
    1478
    1479      """Failed to ALTER %s %s"""
    1480
    1481 -class Sp_Subselect_Nyi(MySQL_Error):
    1482
    1483      """Subselect value not supported"""
    1484
    1485 -class Stmt_Not_Allowed_In_Sf_Or_Trg(MySQL_Error):
    1486
    1487      """%s is not allowed in stored function or trigger"""
    1488
    1489 -class Sp_Varcond_After_Curshndlr(MySQL_Error):
    1490
    1491      """Variable or condition declaration after cursor or handler declaration"""
    1492
    1493 -class Sp_Cursor_After_Handler(MySQL_Error):
    1494
    1495      """Cursor declaration after handler declaration"""
    1496
    1497 -class Sp_Case_Not_Found(MySQL_Error):
    1498
    1499      """Case not found for CASE statement"""
    1500
    1501 -class Fparser_Too_Big_File(MySQL_Error):
    1502
    1503      """Configuration file '%s' is too big"""
    1504
    1505 -class Fparser_Bad_Header(MySQL_Error):
    1506
    1507      """Malformed file type header in file '%s'"""
    1508
    1509 -class Fparser_Eof_In_Comment(MySQL_Error):
    1510
    1511      """Unexpected end of file while parsing comment '%s'"""
    1512
    1513 -class Fparser_Error_In_Parameter(MySQL_Error):
    1514
    1515      """Error while parsing parameter '%s' (line: '%s')"""
    1516
    1517 -class Fparser_Eof_In_Unknown_Parameter(MySQL_Error):
    1518
    1519      """Unexpected end of file while skipping unknown parameter '%s'"""
    1520
    1521 -class View_No_Explain(MySQL_Error):
    1522
    1523      """EXPLAIN/SHOW can not be issued; lacking privileges for underlying
    1524      table
    1525      """
    1526
    1527 -class Frm_Unknown_Type(MySQL_Error):
    1528
    1529      """File '%s' has unknown type '%s' in its header"""
    1530
    1531 -class Wrong_Object(MySQL_Error):
    1532
    1533      """'%s.%s' is not %s"""
    1534
    1535 -class Nonupdateable_Column(MySQL_Error):
    1536
    1537      """Column '%s' is not updatable"""
    1538
    1539 -class View_Select_Derived(MySQL_Error):
    1540
    1541      """View's SELECT contains a subquery in the FROM clause"""
    1542
    1543 -class View_Select_Clause(MySQL_Error):
    1544
    1545      """View's SELECT contains a '%s' clause"""
    1546
    1547 -class View_Select_Variable(MySQL_Error):
    1548
    1549      """View's SELECT contains a variable or parameter"""
    1550
    1551 -class View_Select_Tmptable(MySQL_Error):
    1552
    1553      """View's SELECT refers to a temporary table '%s'"""
    1554
    1555 -class View_Wrong_List(MySQL_Error):
    1556
    1557      """View's SELECT and view's field list have different column counts"""
    1558
    1559 -class Warn_View_Merge(MySQL_Error):
    1560
    1561      """View merge algorithm can't be used here for now (assumed undefined
    1562      algorithm)
    1563      """
    1564
    1565 -class Warn_View_Without_Key(MySQL_Error):
    1566
    1567      """View being updated does not have complete key of underlying table in
    1568      it
    1569      """
    1570
    1571 -class View_Invalid(MySQL_Error):
    1572
    1573      """View '%s.%s' references invalid table(s) or column(s) or function(s) or
    1574      definer/invoker of view lack rights to use them
    1575      """
    1576
    1577 -class Sp_No_Drop_Sp(MySQL_Error):
    1578
    1579      """Can't drop or alter a %s from within another stored routine"""
    1580
    1581 -class Sp_Goto_In_Hndlr(MySQL_Error):
    1582
    1583      """GOTO is not allowed in a stored procedure handler"""
    1584
    1585 -class Trg_Already_Exists(MySQL_Error):
    1586
    1587      """Trigger already exists"""
    1588
    1589 -class Trg_Does_Not_Exist(MySQL_Error):
    1590
    1591      """Trigger does not exist"""
    1592
    1593 -class Trg_On_View_Or_Temp_Table(MySQL_Error):
    1594
    1595      """Trigger's '%s' is view or temporary table"""
    1596
    1597 -class Trg_Cant_Change_Row(MySQL_Error):
    1598
    1599      """Updating of %s row is not allowed in %strigger"""
    1600
    1601 -class Trg_No_Such_Row_In_Trg(MySQL_Error):
    1602
    1603      """There is no %s row in %s trigger"""
    1604
    1605 -class No_Default_For_Field(MySQL_Error):
    1606
    1607      """Field '%s' doesn't have a default value"""
    1608
    1609 -class Division_By_Zero(MySQL_Error):
    1610
    1611      """Division by 0"""
    1612
    1613 -class Truncated_Wrong_Value_For_Field(MySQL_Error):
    1614
    1615      """Incorrect %s value: '%s' for column '%s' at row %ld"""
    1616
    1617 -class Illegal_Value_For_Type(MySQL_Error):
    1618
    1619      """Illegal %s '%s' value found during parsing"""
    1620
    1621 -class View_Nonupd_Check(MySQL_Error):
    1622
    1623      """CHECK OPTION on non-updatable view '%s.%s'"""
    1624
    1625 -class View_Check_Failed(MySQL_Error):
    1626
    1627      """CHECK OPTION failed '%s.%s'"""
    1628
    1629 -class Procaccess_Denied_Error(MySQL_Error):
    1630
    1631      """%s command denied to user '%s'@'%s' for routine '%s'"""
    1632
    1633 -class Relay_Log_Fail(MySQL_Error):
    1634
    1635      """Failed purging old relay logs: %s"""
    1636
    1637 -class Passwd_Length(MySQL_Error):
    1638
    1639      """Password hash should be a %d-digit hexadecimal number"""
    1640
    1641 -class Unknown_Target_Binlog(MySQL_Error):
    1642
    1643      """Target log not found in binlog index"""
    1644
    1645 -class Io_Err_Log_Index_Read(MySQL_Error):
    1646
    1647      """I/O error reading log index file"""
    1648
    1649 -class Binlog_Purge_Prohibited(MySQL_Error):
    1650
    1651      """Server configuration does not permit binlog purge"""
    1652
    1653 -class Fseek_Fail(MySQL_Error):
    1654
    1655      """Failed on fseek()"""
    1656
    1657 -class Binlog_Purge_Fatal_Err(MySQL_Error):
    1658
    1659      """Fatal error during log purge"""
    1660
    1661 -class Log_In_Use(MySQL_Error):
    1662
    1663      """A purgeable log is in use, will not purge"""
    1664
    1665 -class Log_Purge_Unknown_Err(MySQL_Error):
    1666
    1667      """Unknown error during log purge"""
    1668
    1669 -class Relay_Log_Init(MySQL_Error):
    1670
    1671      """Failed initializing relay log position: %s"""
    1672
    1673 -class No_Binary_Logging(MySQL_Error):
    1674
    1675      """You are not using binary logging"""
    1676
    1677 -class Reserved_Syntax(MySQL_Error):
    1678
    1679      """The '%s' syntax is reserved for purposes internal to the MySQL server"""
    1680
    1681 -class Wsas_Failed(MySQL_Error):
    1682
    1683      """WSAStartup Failed"""
    1684
    1685 -class Diff_Groups_Proc(MySQL_Error):
    1686
    1687      """Can't handle procedures with differents groups yet"""
    1688
    1689 -class No_Group_For_Proc(MySQL_Error):
    1690
    1691      """Select must have a group with this procedure"""
    1692
    1693 -class Order_With_Proc(MySQL_Error):
    1694
    1695      """Can't use ORDER clause with this procedure"""
    1696
    1697 -class Logging_Prohibit_Changing_Of(MySQL_Error):
    1698
    1699      """Binary logging and replication forbid changing the global server %s"""
    1700
    1701 -class No_File_Mapping(MySQL_Error):
    1702
    1703      """Can't map file: %s, errno: %d"""
    1704
    1705 -class Wrong_Magic(MySQL_Error):
    1706
    1707      """Wrong magic in %s"""
    1708
    1709 -class Ps_Many_Param(MySQL_Error):
    1710
    1711      """Prepared statement contains too many placeholders"""
    1712
    1713 -class Key_Part_0(MySQL_Error):
    1714
    1715      """Key part '%s' length cannot be 0"""
    1716
    1717 -class View_Checksum(MySQL_Error):
    1718
    1719      """View text checksum failed"""
    1720
    1721 -class View_Multiupdate(MySQL_Error):
    1722
    1723      """Can not modify more than one base table through a join view '%s.%s'"""
    1724
    1725 -class View_No_Insert_Field_List(MySQL_Error):
    1726
    1727      """Can not insert into join view '%s.%s' without fields list"""
    1728
    1729 -class View_Delete_Merge_View(MySQL_Error):
    1730
    1731      """Can not delete from join view '%s.%s'"""
    1732
    1733 -class Cannot_User(MySQL_Error):
    1734
    1735      """Operation %s failed for %s"""
    1736
    1737 -class Xaer_Nota(MySQL_Error):
    1738
    1739      """XAER_NOTA: Unknown XID"""
    1740
    1741 -class Xaer_Inval(MySQL_Error):
    1742
    1743      """XAER_INVAL: Invalid arguments (or unsupported command)"""
    1744
    1745 -class Xaer_Rmfail(MySQL_Error):
    1746
    1747      """XAER_RMFAIL: The command cannot be executed when global transaction is
    1748      in the %s state
    1749      """
    1750
    1751 -class Xaer_Outside(MySQL_Error):
    1752
    1753      """XAER_OUTSIDE: Some work is done outside global transaction"""
    1754
    1755 -class Xaer_Rmerr(MySQL_Error):
    1756
    1757      """XAER_RMERR: Fatal error occurred in the transaction branch - check your
    1758      data for consistency
    1759      """
    1760
    1761 -class Xa_Rbrollback(MySQL_Error):
    1762
    1763      """XA_RBROLLBACK: Transaction branch was rolled back"""
    1764
    1765 -class Nonexisting_Proc_Grant(MySQL_Error):
    1766
    1767      """There is no such grant defined for user '%s' on host '%s' on routine
    1768      '%s'
    1769      """
    1770
    1771 -class Proc_Auto_Grant_Fail(MySQL_Error):
    1772
    1773      """Failed to grant EXECUTE and ALTER ROUTINE privileges"""
    1774
    1775 -class Proc_Auto_Revoke_Fail(MySQL_Error):
    1776
    1777      """Failed to revoke all privileges to dropped routine"""
    1778
    1779 -class Data_Too_Long(MySQL_Error):
    1780
    1781      """Data too long for column '%s' at row %ld"""
    1782
    1783 -class Sp_Bad_Sqlstate(MySQL_Error):
    1784
    1785      """Bad SQLSTATE: '%s'"""
    1786
    1787 -class Startup(MySQL_Error):
    1788
    1789      """%s: ready for connections. Version: '%s' socket: '%s' port: %d %s"""
    1790
    1791 -class Load_From_Fixed_Size_Rows_To_Var(MySQL_Error):
    1792
    1793      """Can't load value from file with fixed size rows to variable"""
    1794
    1795 -class Cant_Create_User_With_Grant(MySQL_Error):
    1796
    1797      """You are not allowed to create a user with GRANT"""
    1798
    1799 -class Wrong_Value_For_Type(MySQL_Error):
    1800
    1801      """Incorrect %s value: '%s' for function %s"""
    1802
    1803 -class Table_Def_Changed(MySQL_Error):
    1804
    1805      """Table definition has changed, please retry transaction"""
    1806
    1807 -class Sp_Dup_Handler(MySQL_Error):
    1808
    1809      """Duplicate handler declared in the same block"""
    1810
    1811 -class Sp_Not_Var_Arg(MySQL_Error):
    1812
    1813      """OUT or INOUT argument %d for routine %s is not a variable"""
    1814
    1815 -class Sp_No_Retset(MySQL_Error):
    1816
    1817      """Not allowed to return a result set from a %s"""
    1818
    1819 -class Cant_Create_Geometry_Object(MySQL_Error):
    1820
    1821      """Cannot get geometry object from data you send to the GEOMETRY field"""
    1822
    1823 -class Failed_Routine_Break_Binlog(MySQL_Error):
    1824
    1825      """A routine failed and has neither NO SQL nor READS SQL DATA in its
    1826      declaration and binary logging is enabled; if non-transactional tables were
    1827      updated, the binary log will miss their changes
    1828      """
    1829
    1830 -class Binlog_Unsafe_Routine(MySQL_Error):
    1831
    1832      """This function has none of DETERMINISTIC, NO SQL, or READS SQL DATA in
    1833      its declaration and binary logging is enabled (you *might* want to use the
    1834      less safe log_bin_trust_function_creators variable)
    1835      """
    1836
    1837 -class Binlog_Create_Routine_Need_Super(MySQL_Error):
    1838
    1839      """You do not have the SUPER privilege and binary logging is enabled (you
    1840      *might* want to use the less safe log_bin_trust_function_creators
    1841      variable)
    1842      """
    1843
    1844 -class Exec_Stmt_With_Open_Cursor(MySQL_Error):
    1845
    1846      """You can't execute a prepared statement which has an open cursor
    1847      associated with it. Reset the statement to re-execute it.
    1848      """
    1849
    1850 -class Stmt_Has_No_Open_Cursor(MySQL_Error):
    1851
    1852      """The statement (%lu) has no open cursor."""
    1853
    1854 -class Commit_Not_Allowed_In_Sf_Or_Trg(MySQL_Error):
    1855
    1856      """Explicit or implicit commit is not allowed in stored function or
    1857      trigger.
    1858      """
    1859
    1860 -class No_Default_For_View_Field(MySQL_Error):
    1861
    1862      """Field of view '%s.%s' underlying table doesn't have a default value"""
    1863
    1864 -class Sp_No_Recursion(MySQL_Error):
    1865
    1866      """Recursive stored routines are not allowed."""
    1867
    1868 -class Too_Big_Scale(MySQL_Error):
    1869
    1870      """Too big scale %d specified for column '%s'. Maximum is %d."""
    1871
    1872 -class Too_Big_Precision(MySQL_Error):
    1873
    1874      """Too big precision %d specified for column '%s'. Maximum is %d."""
    1875
    1876 -class M_Bigger_Than_D(MySQL_Error):
    1877
    1878      """For float(M,D), double(M,D) or decimal(M,D), M must be >= D (column
    1879      '%s').
    1880      """
    1881
    1882 -class Wrong_Lock_Of_System_Table(MySQL_Error):
    1883
    1884      """You can't combine write-locking of system '%s.%s' table with other
    1885      tables
    1886      """
    1887
    1888 -class Connect_To_Foreign_Data_Source(MySQL_Error):
    1889
    1890      """Unable to connect to foreign data source - database '%s'!"""
    1891
    1892 -class Query_On_Foreign_Data_Source(MySQL_Error):
    1893
    1894      """There was a problem processing the query on the foreign data source.
    1895      Data source error: '%s'
    1896      """
    1897
    1898 -class Foreign_Data_Source_Doesnt_Exist(MySQL_Error):
    1899
    1900      """The foreign data source you are trying to reference does not exist. Data
    1901      source error : '%s'
    1902      """
    1903
    1904 -class Foreign_Data_String_Invalid_Cant_Create(MySQL_Error):
    1905
    1906      """Can't create federated table. The data source connection string '%s' is
    1907      not in the correct format
    1908      """
    1909
    1910 -class Foreign_Data_String_Invalid(MySQL_Error):
    1911
    1912      """The data source connection string '%s' is not in the correct format"""
    1913
    1914 -class Cant_Create_Federated_Table(MySQL_Error):
    1915
    1916      """Can't create federated table. Foreign data src error : '%s'"""
    1917
    1918 -class Trg_In_Wrong_Schema(MySQL_Error):
    1919
    1920      """Trigger in wrong schema"""
    1921
    1922 -class Stack_Overrun_Need_More(MySQL_Error):
    1923
    1924      """Thread stack overrun: %ld bytes used of a %ld byte stack, and %ld bytes
    1925      needed. Use 'mysqld -O thread_stack=#' to specify a bigger stack.
    1926      """
    1927
    1928 -class Too_Long_Body(MySQL_Error):
    1929
    1930      """Routine body for '%s' is too long"""
    1931
    1932 -class Warn_Cant_Drop_Default_Keycache(MySQL_Error):
    1933
    1934      """Cannot drop default keycache"""
    1935
    1936 -class Too_Big_Displaywidth(MySQL_Error):
    1937
    1938      """Display width out of range for column '%s' (max = %d)"""
    1939
    1940 -class Xaer_Dupid(MySQL_Error):
    1941
    1942      """XAER_DUPID: The XID already exists"""
    1943
    1944 -class Datetime_Function_Overflow(MySQL_Error):
    1945
    1946      """Datetime function: %s field overflow"""
    1947
    1948 -class Cant_Update_Used_Table_In_Sf_Or_Trg(MySQL_Error):
    1949
    1950      """Can't update table '%s' in stored function/trigger because it is already
    1951      used by statement which invoked this stored function/trigger.
    1952      """
    1953
    1954 -class View_Prevent_Update(MySQL_Error):
    1955
    1956      """The definition of table '%s' prevents operation %s on table '%s'."""
    1957
    1958 -class Ps_No_Recursion(MySQL_Error):
    1959
    1960      """The prepared statement contains a stored routine call that refers to
    1961      that same statement. It's not allowed to execute a prepared statement in
    1962      such a recursive manner
    1963      """
    1964
    1965 -class Sp_Cant_Set_Autocommit(MySQL_Error):
    1966
    1967      """Not allowed to set autocommit from a stored function or trigger"""
    1968
    1969 -class Malformed_Definer(MySQL_Error):
    1970
    1971      """Definer is not fully qualified"""
    1972
    1973 -class No_View_User(MySQL_Error):
    1974
    1975      """View definer is not fully qualified
    1976
    1977      (No longer available as of 5.0.17.)
    1978      """
    1979
    1980 -class View_Frm_No_User(MySQL_Error):
    1981
    1982      """View %s.%s has not definer information (old table format). Current user
    1983      is used as definer. Please recreate view!
    1984      """
    1985
    1986 -class View_Other_User(MySQL_Error):
    1987
    1988      """You need the SUPER privilege for creation view with %s@%s definer"""
    1989
    1990 -class No_Such_User(MySQL_Error):
    1991
    1992      """There is no '%s'@'%s' registered"""
    1993
    1994 -class Forbid_Schema_Change(MySQL_Error):
    1995
    1996      """Changing schema from '%s' to '%s' is not allowed."""
    1997
    1998 -class Row_Is_Referenced_2(MySQL_Error):
    1999
    2000      """Cannot delete or update a parent row: a foreign key constraint fails
    2001      (%s)
    2002      """
    2003
    2004 -class No_Referenced_Row_2(MySQL_Error):
    2005
    2006      """Cannot add or update a child row: a foreign key constraint fails (%s)"""
    2007
    2008 -class Sp_Bad_Var_Shadow(MySQL_Error):
    2009
    2010      """Variable '%s' must be quoted with ``...``, or renamed"""
    2011
    2012 -class Trg_No_Definer(MySQL_Error):
    2013
    2014      """No definer attribute for trigger '%s'.'%s'. The trigger will be
    2015      activated under the authorization of the invoker, which may have
    2016      insufficient privileges. Please recreate the trigger.
    2017      """
    2018
    2019  ###############################################################################
    2020  # 5.0.17
    2021  ###############################################################################
    2022
    2023 -class Sp_Recursion_Limit(MySQL_Error):
    2024
    2025      """Recursive limit %d (as set by the max_sp_recursion_depth variable) was
    2026      exceeded for routine %.64s
    2027
    2028      (New in 5.0.17.)
    2029      """
    2030
    2031 -class Malformed_Definer(MySQL_Error):
    2032
    2033      """Definer is not fully qualified
    2034
    2035      (New in 5.0.17.)
    2036      """
    2037
    2038 -class Old_File_Format(MySQL_Error):
    2039
    2040      """'%-.64s' has an old format, you should re-create the '%s' object(s).
    2041      (New in 5.0.17.)
    2042      """
    2043
    2044 -class Trg_No_Definer(MySQL_Error):
    2045
    2046      """No definer attribute for trigger '%-.64s'.'%-.64s'. The trigger will be
    2047      activated under the auth orization of the invoker, which may have
    2048      insufficient privileges. Please recreate the trigger.
    2049
    2050      (New in 5.0.17.)
    2051      """
    2052 -class Sp_Proc_Table_Corrupt(MySQL_Error):
    2053
    2054      """Failed to load routine %s. The table mysql.proc is missing, corrupt, or
    2055      contains bad data (internal code %d)
    2056
    2057      (New in 5.0.17.)
    2058      """
    2059
    2060  ###############################################################################
    2061  # 5.0.19
    2062  ###############################################################################
    2063
    2064 -class Table_Needs_Upgrade(MySQL_Error):
    2065
    2066      """Table upgrade required. Please do "REPAIR TABLE ``%-.32s``" to fix it!
    2067
    2068      (New in 5.0.19.)
    2069      """
    2070
    2071 -class Sp_No_Aggregate(MySQL_Error):
    2072
    2073      """AGGREGATE is not supported for stored functions
    2074
    2075      (New in 5.0.19.)
    2076      """
    2077
    2078 -class Sp_Wrong_Name(MySQL_Error):
    2079
    2080      """Incorrect routine name '%-.64s'
    2081
    2082      (New in 5.0.19.)
    2083      """
    2084
    2085  ###############################################################################
    2086  # 5.0.21
    2087  ###############################################################################
    2088
    2089 -class Max_Prepared_Stmt_Count_Reached(MySQL_Error):
    2090
    2091      """Can't create more than max_prepared_stmt_count statements (current
    2092      value: %lu)
    2093
    2094      (New in 5.0.21.)
    2095      """
    2096
    2097 -class View_Recursive(MySQL_Error):
    2098
    2099      """``%-.64s``.``%-.64s`` contains view recursion.
    2100
    2101      (New in 5.0.21.)
    2102      """
    2103
    2104  ###############################################################################
    2105  # 5.0.23
    2106  ###############################################################################
    2107
    2108 -class Non_Grouping_Field_Used(MySQL_Error):
    2109
    2110      """non-grouping field '%-.64s' is used in %-.64s clause
    2111
    2112      (New in 5.0.23.)
    2113      """
    2114
    2115 -class Table_Cant_Handle_Spkeys(MySQL_Error):
    2116
    2117      """The used table type doesn't support SPATIAL indexes
    2118
    2119      (New in 5.0.23.)
    2120      """
    2121
    2122 -class No_Triggers_On_System_Schema(MySQL_Error):
    2123
    2124      """Triggers can not be created on system tables
    2125
    2126      (New in 5.0.23.)
    2127      """
    2128
    2129  ###############################################################################
    2130  # 5.0.24a
    2131  ###############################################################################
    2132
    2133 -class Username(MySQL_Error):
    2134
    2135      """user name?
    2136
    2137      (New in 5.0.24a.)
    2138      """
    2139
    2140 -class Hostname(MySQL_Error):
    2141
    2142      """host name?
    2143
    2144      (New in 5.0.24a.)
    2145      """
    2146
    2147 -class Wrong_String_Length(MySQL_Error):
    2148
    2149      """String '%-.70s' is too long for %s (should be no longer than %d)
    2150
    2151      (New in 5.0.24a.)
    2152      """
    2153
    2154  ###############################################################################
    2155  # 5.0.25
    2156  ###############################################################################
    2157
    2158 -class Removed_Spaces(MySQL_Error):
    2159
    2160      """Leading spaces are removed from name '%s'
    2161
    2162      (New in 5.0.25.)
    2163      """
    2164
    2165 -class Autoinc_Read_Failed(MySQL_Error):
    2166
    2167      """Failed to read auto-increment value from storage engine
    2168
    2169      (New in 5.0.25.)
    2170      """
    2171
    2172 -class Non_Insertable_Table(MySQL_Error):
    2173
    2174      """The target table %-.100s of the %s is not insertable-into
    2175
    2176      (New in 5.0.25.)
    2177      """
    2178